{ pkgs, lib, username, ... }:

{
  imports = [
    ./disko.nix
    ./packages.nix
  ];

  time.timeZone = "Europe/Berlin";

  console = {
    earlySetup = true;
    keyMap = "de";
  };

  networking = {
    hostName = "x220";
    useDHCP = lib.mkDefault true;
  };

  boot = {
    loader = {
      efi.canTouchEfiVariables = true;
      grub = {
        enable = true;
        # device = "/dev/sda"; # [managed by install.sh]
        gfxmodeEfi = "1366x768";
      };
    };

    tmp.useTmpfs = true;
    kernelPackages = pkgs.unstable.linuxPackages_xanmod_latest;
    supportedFilesystems = [ "btfs" "vfat" "xfs" ];
    initrd = {
      availableKernelModules = [ "ehci_pci" "ahci" "xhci_pci"
                                 "usb_storage" "sd_mod" "sdhci_pci" ];
    };
  };

  services = {
    fstrim.enable = true;
    btrfs.autoScrub.enable = true;
  };

  fileSystems = {
    # These are system specific. If you have any additional drives that are not
    # your root device you can add and mount them here. Added nofail so that you can
    # install this configuration on a device without it exploding when you don't have
    # these specific partitions.
  };

  system.stateVersion = "24.11"; # [managed by install.sh] { state version }
}

